==> Molsketch-0.3.0-src.tar.gz: Molsketch-0.3.0/libmolsketch/src/actions/bondtypewidget.h <==
/***************************************************************************
 *   Copyright (C) 2015 Hendrik Vennekate                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef BONDTYPEWIDGET_H
#define BONDTYPEWIDGET_H

#include "itemtypewidget.h"
#include "bond.h"

namespace Molsketch {

  class bondTypeWidget : public ItemTypeWidget
  {
  public:
    explicit bondTypeWidget(bool withInversion, QWidget *parent = 0);
    bool backward() const ;
    Bond::BondType bondType() const ;
    void setBondType(Bond::BondType type) const;
  };

} // namespace

#endif // BONDTYPEWIDGET_H

==> Molsketch-0.4.1-src.tar.gz: Molsketch-0.4.1/libmolsketch/src/actions/bondtypewidget.h <==
/***************************************************************************
 *   Copyright (C) 2015 Hendrik Vennekate                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef BONDTYPEWIDGET_H
#define BONDTYPEWIDGET_H

#include "itemtypewidget.h"
#include "bond.h"

namespace Molsketch {

  class bondTypeWidget : public ItemTypeWidget
  {
  public:
    explicit bondTypeWidget(bool withInversion, QWidget *parent = 0);
    bool backward() const ;
    Bond::BondType bondType() const ;
    void setBondType(Bond::BondType type);
  };

} // namespace

#endif // BONDTYPEWIDGET_H
